@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2019-2020 Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2018-2020 Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -22,13 +22,13 @@ prefix="/usr"
 if [ -e ${prefix}/share/kea/scripts/admin-utils.sh ]; then
     . "${prefix}/share/kea/scripts/admin-utils.sh"
 else
-    . "/build/kea/src/kea-1.9.6/src/bin/admin/admin-utils.sh"
+    . "/build/kea/src/kea-2.0.2/src/bin/admin/admin-utils.sh"
 fi
 
 VERSION=$(pgsql_version "$@")
 
-if [ "$VERSION" != "5.0" ]; then
-    printf 'This script upgrades 5.0 to 5.1. '
+if [ "$VERSION" != "3.2" ]; then
+    printf 'This script upgrades 3.2 to 3.3. '
     printf 'Reported version is %s. Skipping upgrade.\n' "${VERSION}"
     exit 0
 fi
@@ -37,14 +37,18 @@ psql "$@" >/dev/null <<EOF
 
 START TRANSACTION;
 
--- Put the auth key in hexadecimal (double size but far more user friendly).
-ALTER TABLE hosts ALTER COLUMN auth_key TYPE VARCHAR(32);
+-- Change subnet ID columns type to BIGINT to match lease4/6 tables
+ALTER TABLE hosts ALTER COLUMN dhcp4_subnet_id TYPE BIGINT;
+ALTER TABLE hosts ALTER COLUMN dhcp6_subnet_id TYPE BIGINT;
 
--- Set 5.1 schema version.
+ALTER TABLE dhcp4_options ALTER COLUMN dhcp4_subnet_id TYPE BIGINT;
+ALTER TABLE dhcp6_options ALTER COLUMN dhcp6_subnet_id TYPE BIGINT;
+
+-- Set 3.3 schema version.
 UPDATE schema_version
-    SET version = '5', minor = '1';
+    SET version = '3', minor = '3';
 
--- Schema 5.1a specification ends here.
+-- Schema 3.3 specification ends here.
 
 -- Commit the script transaction
 COMMIT;
